=======
pyaavso
=======

.. image:: https://pypip.in/v/pyaavso/badge.png
    :target: https://crate.io/packages/pyaavso/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pyaavso/badge.png
    :target: https://crate.io/packages/pyaavso/
    :alt: Number of PyPI downloads

.. image:: https://travis-ci.org/zsiciarz/pyaavso.png?branch=master
    :target: https://travis-ci.org/zsiciarz/pyaavso

A Python library for working with `AAVSO <http://www.aavso.org>`_ (American
Association of Variable Star Observers) data.

Resources
---------

 * `Documentation <http://pyaavso.rtfd.org>`_
 * `Issue tracker <https://github.com/zsiciarz/pyaavso/issues>`_

Author
------

 * `Zbigniew Siciarz <http://siciarz.net>`_ (zbigniew at siciarz dot net)

License
-------

This work is released under the MIT license. A copy of the license is provided
in the LICENSE file.

